@@ -572,6 +572,9 @@ class Snowflake(Dialect):
             exp.Exp,
             exp.Sin,
             exp.Tan,
+            exp.Asin,
+            exp.Atanh,
+            exp.Cbrt,
         },
         exp.DataType.Type.INT: {
             *Dialect.TYPE_TO_EXPRESSIONS[exp.DataType.Type.INT],
@@ -629,6 +632,7 @@ class Snowflake(Dialect):
         },
         exp.DataType.Type.BIGINT: {
             *Dialect.TYPE_TO_EXPRESSIONS[exp.DataType.Type.BIGINT],
+            exp.Factorial,
             exp.MD5NumberLower64,
             exp.MD5NumberUpper64,
         },
@@ -660,11 +664,13 @@ class Snowflake(Dialect):
         **{
             expr_type: lambda self, e: self._annotate_by_args(e, "this")
             for expr_type in (
+                exp.Floor,
                 exp.Left,
                 exp.Pad,
                 exp.Right,
                 exp.Stuff,
                 exp.Substring,
+                exp.Round,
             )
         },
         **{
