@@ -1543,6 +1543,18 @@ BIGINT;
 ABS(tbl.double_col);
 DOUBLE;
 
+# dialect: snowflake
+ASIN(tbl.double_col);
+DOUBLE;
+
+# dialect: snowflake
+ATANH(tbl.double_col);
+DOUBLE;
+
+# dialect: snowflake
+CBRT(tbl.double_col);
+DOUBLE;
+
 # dialect: snowflake
 AI_AGG('foo', 'bar');
 VARCHAR;
@@ -1767,6 +1779,22 @@ DOUBLE;
 EXP(5.5);
 DOUBLE;
 
+# dialect: snowflake
+FACTORIAL(5);
+BIGINT;
+
+# dialect: snowflake
+FLOOR(42);
+INT;
+
+# dialect: snowflake
+FLOOR(135.135, 1);
+DOUBLE;
+
+# dialect: snowflake
+FLOOR(tbl.bigint_col, -1);
+BIGINT;
+
 # dialect: snowflake
 ENDSWITH('hello world', 'world');
 BOOLEAN;
@@ -1895,6 +1923,14 @@ INT;
 LOWER(tbl.str_col);
 VARCHAR;
 
+# dialect: snowflake
+LN(tbl.double_col);
+DOUBLE;
+
+# dialect: snowflake
+LOG(tbl.double_col);
+DOUBLE;
+
 # dialect: snowflake
 LTRIM('  hello world  ');
 VARCHAR;
